@@ -200,7 +200,6 @@ main (int    argc,
   context = g_option_context_new ("- Presentations made easy");
   g_option_context_add_main_entries (context, entries, NULL);
   g_option_context_add_group (context, clutter_get_option_group_without_init ());
-  g_option_context_add_group (context, cogl_get_option_group ());
   if (!g_option_context_parse (context, &argc, &argv, &error))
     {
       g_print ("option parsing failed: %s\n", error->message);
@@ -225,10 +224,11 @@ main (int    argc,
         }
     }
 
+  if (!gtk_clutter_init (&argc, &argv))
+    return EXIT_FAILURE;
 #ifdef USE_CLUTTER_GST
-  clutter_gst_init (&argc, &argv);
-#else
-  clutter_init (&argc, &argv);
+  if (!clutter_gst_init (&argc, &argv))
+    return EXIT_FAILURE;
 #endif
 #ifdef USE_DAX
   dax_init (&argc, &argv);
@@ -952,17 +952,19 @@ pp_parse_slides (PinPointRenderer *renderer,
               }
             break;
         case '#': /* comment */
-          if (startofline && ! pp_ignore_comments)
+          if (startofline)
             {
               const char *end = p + 1;
               while (*end != '\n' && *end != '\0')
                 {
-                  g_string_append_c (notes_str, *end);
+                  if (!pp_ignore_comments)
+                    g_string_append_c (notes_str, *end);
                   end++;
                 }
               if (end)
                 {
-                  g_string_append_c (notes_str, '\n');
+                  if (!pp_ignore_comments)
+                    g_string_append_c (notes_str, '\n');
                   p = end;
                   break;
                 }
